@@ -2,7 +2,8 @@
 #define HAUPPAUGE_H
 
 #include "pirkeysetmetadata.h"
-#include <QObject>
+
+class QObject;
 
 class HauppaugePCTV1: public PIRKeysetMetaData
 {
