@@ -10,7 +10,9 @@ enum PIRMakeName{
   Admiral_Make,
   Aiwa_Make,
   Apple_Make,
+  Beko_Make,
   Bose_Make,
+  Cambridge_Make,
   Daewoo_Make,
   Denon_Make,
   DigitalStream_Make,
@@ -21,10 +23,12 @@ enum PIRMakeName{
   Fortec_Make,
   GoldStar_Make,
   Grundig_Make,
+  Haier_Make,
   Hauppauge_Make,
   Hitachi_Make,
   Homecast_Make,
   JVC_Make,
+  Kenwood_Make,
   LG_Make,
   Logitech_Make,
   Magnavox_Make,
